# Rotordynamic Open Source Software (ROSS)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/ross-rotordynamics/ross/master)
[![Build Status](https://travis-ci.com/ross-rotordynamics/ross.svg?branch=master)](https://travis-ci.com/ross-rotordynamics/ross)
[![Build status](https://ci.appveyor.com/api/projects/status/tvsj4jh7bowvn0ht/branch/master?svg=true)](https://ci.appveyor.com/project/raphaeltimbo/ross/branch/master)
<a href="https://codecov.io/gh/ross-rotordynamics/ross">
<img src="https://codecov.io/gh/ross-rotordynamics/ross/branch/master/graph/badge.svg">
</a>
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)

Ross is a library written in Python for rotordynamic analysis.

You can try it out now by running the tutorial on [binder](https://mybinder.org/v2/gh/ross-rotordynamics/ross/master).
After binder starts, navigate to the ross/docs/examples directory and open the tutorial notebook.

# Documentation 
Access the documentation [here](https://ross-rotordynamics.github.io/ross-website/).
There you can find the [installation procedure](https://ross-rotordynamics.github.io/ross-website/installation.html), 
[a tutorial](https://ross-rotordynamics.github.io/ross-website/examples/tutorial.html), 
[examples](https://ross-rotordynamics.github.io/ross-website/examples.html) and the 
[API reference](https://ross-rotordynamics.github.io/ross-website/api.html).

# Questions
If you have any questions you can open a new issue with the tag <question>.

# Contributing to ROSS
Check [CONTRIBUTING.rst](https://github.com/ross-rotordynamics/ross/blob/master/CONTRIBUTING.rst).
